#
# spec file for package libspectre
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define debug_package_requires libspectre1 = %{version}-%{release}
Name:           libspectre
Version:        0.2.12
Release:        1.4
Summary:        Library for Rendering PostScript Documents
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://libspectre.freedesktop.org/
Source0:        https://libspectre.freedesktop.org/releases/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-bsc975503.diff bsc#975503 fdo#97091 -- Parse ps files ignoring EOF comments which would stop parsing too soon in documents with embedded EPS files.
Patch0:         fix-bsc975503.diff
BuildRequires:  ghostscript-devel >= 9.53.0
BuildRequires:  ghostscript-library
BuildRequires:  pkgconfig

%description
libspectre is a small library for rendering Postscript documents. It
provides a convenient easy to use API for handling and rendering
Postscript documents.

%package -n libspectre1
Summary:        Library for Rendering PostScript Documents
Group:          Development/Libraries/C and C++

%description -n libspectre1
libspectre is a small library for rendering Postscript documents. It
provides a convenient easy to use API for handling and rendering
Postscript documents.

%package -n libspectre-devel
Summary:        Library for Rendering PostScript Documents
Group:          Development/Libraries/C and C++
Requires:       libspectre1 >= %{version}
%requires_eq    ghostscript-devel

%description -n libspectre-devel
libspectre is a small library for rendering Postscript documents. It
provides a convenient easy to use API for handling and rendering
Postscript documents.

%prep
%setup -q
%patch0 -p1

%build
%configure --disable-static --enable-shared
%make_build

%install
%make_install

%post -n libspectre1 -p /sbin/ldconfig
%postun -n libspectre1 -p /sbin/ldconfig

%files -n libspectre1
%license COPYING
%{_libdir}/libspectre.so.1*

%files -n libspectre-devel
%{_includedir}/libspectre
%{_libdir}/libspectre.la
%{_libdir}/libspectre.so
%{_libdir}/pkgconfig/libspectre.pc

%changelog
* Wed Jan 18 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2.12:
  * This is another bugfix only release in the libspectre's 0.2 series.
  * Fix exporting to PDF with newer ghostscript (Albert Astals Cid)
* Tue Nov  8 2022 Dirk Müller <dmueller@suse.com>
- update to 0.2.11:
  * Avoid possible crash when loading a document
* Sun Mar 20 2022 Dirk Müller <dmueller@suse.com>
- update to 0.2.10:
  * Fix display of some EPS files
  * Fixed memory leak in in case spectre_presize is called multiple
    times
  * Use the new api to pass the callbacks to libgs. Needs
    ghostscript >= 9.53
* Thu Aug 20 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.2.9:
  * Fixed lots of crashes, memory leaks with malformed
  documents (Albert Astals Cid, Randy)
  * Ghostscript 9.24 is now required (Christian Persch)
  * Hide internal symbols (Christian Persch)
  * Added "(libspectre)" to the error messages to be clear where the
  messages come from (Caolán McNamara)
  * Fixed clang warnings (Albert Astals Cid)
- fix-bsc975503.diff: refresh
* Tue Aug 23 2016 alarrosa@suse.com
- Add fix-bsc975503.diff to fix handling of PostScript files with
  embedded EPS files. The PS file then contains two "%%%%EOF" DSC
  comments and the first one stopped the parsing of the file as if
  the real EOF was reached (bsc#975503, fdo#97091).
* Sat Jul  2 2016 zaitor@opensuse.org
- Update to version to version 0.2.8:
  + Fixed the document rotation with newer versions of Ghostscript
    (fdo#76450).
  + Build was also broken with Ghostscript >= 9.18 and has been
    fixed.
  + Fixed a compile warning due to a comparison of integers of
    different signs when building on OS X (fdo#56476).
  + Makefiles were updated to properly use CPPFLAGS instead of
    CFLAGS (fdo#56481).
- Drop libspectre-gs-9.18.patch and
  libspectre-rotate-documents-correctly.patch: Fixed upstream.
- Drop zypper BuildRequires: It was only needed for above patches.
* Sun Nov  8 2015 badshah400@gmail.com
- Add libspectre-rotate-documents-correctly.patch to fix documents
  being rotated incorrectly; patch taken from upstream bug
  report (fdo#76450,boo#898327).
* Wed Nov  4 2015 dimstar@opensuse.org
- Replace the logic in the prep section to use zypper in order to
  verify the version. The previous version had issues on openSUSE
  13.2.
* Wed Nov  4 2015 dimstar@opensuse.org
- Add libspectre-gs-9.18.patch: Fix building with ghostscript 9.18;
  patch only applied when building against GS 9.18+ (boo#953149).
* Thu Jan  9 2014 hrvoje.senjan@gmail.com
- Add COPYING to %%doc of the library subpackage (bnc#857790)
* Sun Oct 21 2012 zaitor@opensuse.org
- Update to version 0.2.7:
  + This release fixes two crashes that can happen when %%%%Pages:
    or %%%%Page: comments are missing in the document or when
    %%%%Pages: comment is present but it's invalid.
- Changed tarball into upstream default gz.
- Updated url and sourcelinks to valid locations.
* Mon Aug  9 2010 vuntz@opensuse.org
- Update to version 0.2.6:
  + The most important change in this release is that gs is now
    always initalized with the flag -P- to make Ghostscript not
    look in the current directory for library files. See
    deb#583183.
  + Compiler flags -ansi and -pedantic are now optional and can be
    enabled with --enable-iso-c configure option. (fdo#27735)
  + Files with a doseps header and without EOF comment are
    correctly rendered now. (fdo#27830)
- Changes from version 0.2.5:
  + Fix a portability issue that caused crashes on big-endian 64
    bit systems. See lp#298139.
  + Fix a crash when something goes wrong while running pdf
    exporter. (fdo#26592)
- Add pkg-config BuildRequires to have pkgconfig() Provides.
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 0.2.4:
  + Documents containing embedded documents inside the prolog,
    typically font resources, were not correctly rendered
    (fdo#25573)
  + Fix some portability issues to make libspectre build and work
    on Windows (fdo#26377)
  + PDF exporter was broken which might cause a crash when printing
    some documents (fdo#26592)
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 0.2.3:
  + Several fixes in the PostScript parser:
  - Detection of invalid or broken files has been improved. A
    document scanned without errors with no pages and no format
    is likely to be an invalid file, or not a PostScript file at
    all (fdo#19042)
  - Fix possible uninitialized use of Document media struct
    contents(fdo#18685)
  - Fix documents with PJL commands before the initial DSC
    comments.
  + Ghostscript is now always run with -dSAFER option
  + A missing argument in gs command line of PDF exporter was
    making it always fail for any document in BSD systems
    (fdo#18826)
  + Internal copy of ghostscript headers have been removed since
    they are already installed by ghostscript since version 8.62
    (fdo#18827)
- Do not call suse_update_config, and do not reset CFLAGS to
  default value.
* Thu Feb  5 2009 vuntz@novell.com
- Update to version 0.2.2:
  + A problem when rendering some documents where the page size is
    different from the Bounding Box has been fixed (fdo#18239)
  + Parser is now locale-independent when parsing float numbers
    (fdo#18685)
  + The display format has been fixed to match cairo/pixman.
    (fdo#18266)
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Wed Oct 15 2008 stbinner@suse.de
- update to 0.2.1:
  * Fixes and improvements in the PostScript parser
  * Portability fixes
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Thu Apr  3 2008 dmueller@suse.de
- Initial package (0.2.0)
